@@ -33,6 +33,14 @@ class BearerTokenAuthScheme : public AuthScheme<AwsBearerTokenIdentityBase>
         assert(m_signer);
     }
 
+    explicit BearerTokenAuthScheme(const Aws::String &serviceName, const Aws::String &region,
+                                   const Aws::Client::ClientConfiguration::CredentialProviderConfiguration& config)
+        : BearerTokenAuthScheme(Aws::MakeShared<DefaultAwsBearerTokenIdentityResolver>("BearerTokenAuthScheme"), serviceName, region) {
+      AWS_UNREFERENCED_PARAM(config);
+      assert(m_identityResolver);
+      assert(m_signer);
+    }
+
     explicit BearerTokenAuthScheme(const Aws::String &serviceName,
                                    const Aws::String &region)
         : BearerTokenAuthScheme(
